# ../scripts/custom/gg_hostname_manager/gg_hostname_manager.py

# =============================================================================
# >> IMPORTS
# =============================================================================
# Python Imports
from configobj import ConfigObj
from path import path

# EventScripts
#   ES
from es import ServerVar
#   Gamethread
from gamethread import cancelDelayed
from gamethread import delayedname

# GunGame Imports
#   Modules
from gungame51.modules.backups import VariableBackups
#   Addons
from gungame51.core.addons.loaded import LoadedAddons
from gungame51.core.addons.info import AddonInfo

# =============================================================================
# >> ADDON REGISTRATION
# =============================================================================
info = AddonInfo()
info.name = 'gg_hostname_manager'
info.title = 'GG HostName Manager'
info.author = 'Satoon101'
info.version = '1.1'

# =============================================================================
# >> PUBLIC VARIABLE
# =============================================================================
ServerVar(info.name + '_version', info.version,
        info.title + ' Version').set(info.version)
ServerVar(info.name + '_version').makepublic()

# =============================================================================
# >> GLOBAL VARIABLES
# =============================================================================
# Get all values from the strings.ini file
manager = ConfigObj(path(__file__).parent.joinpath('strings.ini'))


# =============================================================================
# >> LOAD & UNLOAD
# =============================================================================
def load():
    '''Called when the script loads'''

    # Store the default value of hostname
    VariableBackups['hostname'].add(info.name)

    # Set the hostname on load
    delayedname(0.1, info.name, set_hostname)


def unload():
    '''Called when the script unloads'''

    # Reset the hostname to its default value
    VariableBackups['hostname'].remove(info.name)


# =============================================================================
# >> GAME EVENTS
# =============================================================================
def gg_addon_loaded(event_var):
    '''Called when a GunGame51 addon is loaded'''

    # Is the addon in the strings.ini?
    if event_var['addon'] in manager:

        # Cancel any current delay
        cancelDelayed(info.name)

        # Set the new value of hostname
        delayedname(0.1, info.name, set_hostname)


def gg_addon_unloaded(event_var):
    '''Called when a GunGame51 addon is unloaded'''

    # Is the addon in the strings.ini?
    if event_var['addon'] in manager:

        # Cancel any current delay
        cancelDelayed(info.name)

        # Set the new value of hostname
        delayedname(0.1, info.name, set_hostname)


def set_hostname():
    '''Sets the hostname to show GunGame and Included/Custom Addons'''

    # Get the basename
    value = manager['Settings']['basename']

    # Create an empty dictionary
    values = {}

    # Loop through all addons in the strings.ini
    for addon_name in manager:

        # Is the addon loaded?
        if addon_name in LoadedAddons:

            # Get the addon's values from the strings.ini
            addon = manager[addon_name]

            # Store the addon's name and priority
            values[addon['name']] = int(addon['priority'])

    # Are there any addons that are loaded?
    if values:

        # Add the base_break to the string
        value += manager['Settings']['base_break']

        # Sort the loaded addons by their priority
        addons = sorted(values, key=lambda addon: values[addon])

        # Add all loaded addons to the string
        # Separate each with the feature_break
        value += manager['Settings']['feature_break'].join(addons)

    # Set the hostname to the new value
    ServerVar('hostname').set(value)
